@@ -2,7 +2,10 @@
 from django.test import TestCase, RequestFactory
 from django.core.urlresolvers import resolve
 from django.contrib.auth import authenticate
-from django.utils import simplejson
+try:
+    import json as simplejson
+except ImportError:
+    from django.utils import simplejson
 from django.contrib.auth.models import AnonymousUser
 from django.db.utils import IntegrityError
 from urlparse import urlsplit, urlunsplit
